@@ -9,27 +9,36 @@
 package Debug::Easy;
 
 use strict;
+use constant {
+    TRUE  => 1,
+    FALSE => 0
+};
 
 use Term::ANSIColor;
 use Log::Fast;
 use Time::HiRes qw(time);
-use Data::Printer {
-      'alias'          => 'Dumper',
-      'use_prototypes' => 0,
-      'colored'        => 1,
-      'hash_separator' => ' => ',
-      'indent'         => 3,
-      'deparse'        => 1,
-      'class'          => {
-          'expand' => 'all'
-      },
+use Module::Load::Conditional qw(can_load);
+
+my $Modules = {
+    'Data::Printer'        => 0,
+    'Data::Dumper::Simple' => 0,
+    'Data::Dumper'         => 0
 };
+if (can_load('modules' => { 'Data::Printer' => 0.30 },'autoload' => TRUE)) {
+    $Modules->{'Data::Printer'}++;
+} elsif (can_load('modules' => { 'Data::Dumper::Simple' => 0.10 },'autoload' => TRUE)) {
+    $Modules->{'Data::Dumper::Simple'}++;
+} else {
+    can_load('modules' => { 'Data::Dumper' => 0 },'autoload' => TRUE);
+    $Modules->{'Data::Dumper'}++;
+}
+
 
 BEGIN {
     require Exporter;
 
     # set the version for version checking
-    our $VERSION = 0.20;
+    our $VERSION = 0.30;
 
     # Inherit from Exporter to export functions and variables
     our @ISA = qw(Exporter);
@@ -59,9 +68,6 @@ Debug::Easy - A Handy Debugging Module
 
  my $debug = Debug::Easy->new( 'LogLevel' => 'DEBUG', 'Color' => 1 );
 
- # The first parameter to pass to the object is the line number.
- # Typically this is the Perl internal variable '__LINE__'.
- #
  # $debug_level is the maximum level to report, and ignore the rest.
  # It must be the second parameter passed to the object, when outputing
  # a specific message.  This identifies to the module what type of
@@ -79,34 +85,34 @@ Debug::Easy - A Handy Debugging Module
  #              Very useful for verbose modes in your scripts.
  #  DEBUG     = Level 1 Debugging messages
  #  DEBUGMAX  = Level 2 Debugging messages
- #  DEBUGWAIT = Level 3 Debugging where execution is halted until a key
- #              is pressed (EXPERIMENTAL!!)
  #
  # The third parameter is either a string or a reference to an array
- # of strings to output as multiple lines.
+ # of strings to output as multiple lines.  If one of the array
+ # elements is a reference, then it is passed to the available
+ # Data Dumping library.
  #
  # Each string can contain newlines, which will also be split into
  # a separate line and formatted accordingly.
 
  my $debug_level = 'NOTICE';
 
- $debug->debug(__LINE__,$debug_level,"Message");
-
- $debug->debug(__LINE__,'ERR',      ['Error message']);
- $debug->debug(__LINE__,'WARN',     ['Warning message']);
- $debug->debug(__LINE__,'NOTICE',   ['Notice message']);
- $debug->debug(__LINE__,'INFO',     ['Information and VERBOSE mode message']);
- $debug->debug(__LINE__,'DEBUG',    ['Level 1 Debug message']);
- $debug->debug(__LINE__,'DEBUGMAX', ['Level 2 Debug message']);
- $debug->debug(__LINE__,'DEBUGWAIT',['Level 3 Debug message with wait']);
+ $debug->debug($debug_level,"Message");
 
+ $debug->debug('ERR',      ['Error message']);
+ $debug->debug('WARN',     ['Warning message']);
+ $debug->debug('NOTICE',   ['Notice message']);
+ $debug->debug('INFO',     ['Information and VERBOSE mode message']);
+ $debug->debug('DEBUG',    ['Level 1 Debug message']);
+ $debug->debug('DEBUGMAX', ['Level 2 Debug message']);
+ 
  my @messages = (
     'First Message',
-    'Second Message','
-    "Third Message First Line\nThird Message Second Line"
+    'Second Message',
+    "Third Message First Line\nThird Message Second Line",
+    \%hash_reference
  );
 
- $debug->debug(__LINE__,$debug_level,\@messages);
+ $debug->debug($debug_level,\@messages);
 
 =head1 DESCRIPTION
 
@@ -183,6 +189,11 @@ This level can be used as a way to do "Verbose" output for your
 scripts.  It ouputs INFO level messages without logging headers
 and on STDOUT instead of STDERR.
 
+NOTE:  A question was asked why this uses STDOUT.  The answer is
+simple, I have never run across a script that sent "verbose"
+output on STDERR.  If you don't like this behavior, then just use
+the 'INFO' log level instead of 'VERBOSE'.
+
 =item B<DEBUG>
 
 This level shows error, warning, notice, information, and level 1
@@ -192,9 +203,13 @@ debugging messages.  Level 2 Debug messages are not shown.
 
 This level shows all messages up to level 2 debugging messages.
 
-=item B<DEBUGWAIT>
-
-This level shows all messages, but also waits for a keypress.
+NOTE:  It has been asked "Why have two debugging levels?"  Well,
+I have had many times where I would like to see what a script is
+doing without it showing what I consider garbage overhead it may
+generate.  This is simply because the part of the code you are
+debugging you may not need such a high level of detail.  I use
+'DEBUGMAX' to show me absolutely everything.  Such as Data::Dumper
+output.
 
 =back
 
@@ -217,6 +232,8 @@ This level shows all messages, but also waits for a keypress.
 
 =item B<TimeStamp> [pattern]
 
+(See Log::Fast for specifics on these)
+
 Make this an empty string to turn it off, otherwise:
 
 =over 2
@@ -240,6 +257,8 @@ Make this an empty string to turn it off, otherwise:
 
 =item B<DateStamp> [pattern]
 
+(See Log::Fast for specifics on these)
+
 Make this an empty string to turn it off, otherwise:
 
 =over 2
@@ -291,7 +310,6 @@ Make this an empty string to turn it off, otherwise:
      'INFO'      => colored(['white on_black'],     '[ INFO  ]'),
      'DEBUG'     => colored(['bold green on_black'],'[ DEBUG ]'),
      'DEBUGMAX'  => colored(['bold green on_black'],'[-DEBUG-]'),
-     'DEBUGWAIT' => colored(['bold green on_black'],'[*DEBUG*]')
   }
 
 
@@ -333,7 +351,7 @@ sub new {
             'INFO'      => colored(['white on_black'],     '[ INFO  ]'),
             'DEBUG'     => colored(['bold green on_black'],'[ DEBUG ]'),
             'DEBUGMAX'  => colored(['bold green on_black'],'[-DEBUG-]'),
-            'DEBUGWAIT' => colored(['bold green on_black'],'[*DEBUG*]')
+            'DEBUGWAIT' => colored(['bold green on_black'],'[*DEBUG*]') # This is highly experimental! Don't whine about it to me, if you use it.
         },
         @_
     };
@@ -393,7 +411,7 @@ sub new {
         }
     );
     # Signal the script has started (and logger initialized)
-    $self->{'LOG'}->DEBUG('   %.02f%s %s', 0, $self->{'ANSILEVEL'}->{'DEBUG'}, colored(['black on_white'], '----- Script begin -----'));
+    $self->{'LOG'}->DEBUG('   %.02f%s %s', 0, $self->{'ANSILEVEL'}->{'DEBUG'}, colored(['black on_white'], "----- $0 begin -----"));
     bless($self, $class);
     return ($self);
 } ## end sub new
@@ -404,10 +422,6 @@ The parameters must be passed in the order given
 
 =over 1
 
-=item B<LINE>
-
- The line number with which the debug was called.  Typically '__LINE__'
-
 =item B<LEVEL>
 
  The log level with which this message is to be triggered
@@ -422,10 +436,13 @@ The parameters must be passed in the order given
 
 sub debug {
     my $self  = shift;
-    my $cline = shift;
     my $level = shift;
     my $msgs  = shift;
 
+    if ($level !~ /ERR|WARN|NOTICE|INFO|DEBUG/i) { # Compatibility with older versions.
+        $level = $msgs;
+        $msgs = shift;
+    }
     my @messages;
 
     if (ref($msgs) eq 'SCALAR' || ref($msgs) eq '') {
@@ -433,9 +450,13 @@ sub debug {
     } elsif (ref($msgs) eq 'ARRAY') {
         @messages = @{$msgs};
     } else {
-        push(@messages, Dumper($msgs));
+        if ($Modules->{'Data::Printer'}) {
+            push(@messages, p($msgs));
+        } else {
+            push(@messages, Dumper($msgs));
+        }
     }
-
+    my ($p,$f,$cline) = caller; # We get the real line number from here (hopefully).
     my ($package, $filename, $line, $subroutine, $hasargs, $wantarray, $evaltext, $is_require, $hints, $bitmask) = caller(1);
     if (!defined($subroutine) || $subroutine eq '') {    # If there is no subroutine name, then it's usually the "main" namespace
         $subroutine = 'main';
@@ -486,7 +507,7 @@ sub _send_to_logger {    # This actually simplifies the previous class
                 $self->{'LOG'}->DEBUG($thisBench2 . $nested . ' ' . $msg);
             }
         }
-    } elsif ($level eq 'DEBUGWAIT') {                              # Same as above, but waits for a keypress.  EXPERIMENTAL
+    } elsif ($level eq 'DEBUGWAIT') {                              # Same as above, but waits for a keypress.  HIGHLY EXPERIMENTAL, no whining
         if ($self->{'LOGLEVEL'} eq 'DEBUGWAIT') {
             if ($first) {
                 $self->{'LOG'}->DEBUG($thisBench . $nested . $msg);
@@ -531,7 +552,7 @@ modify it under the same terms as Perl itself.
 
 =head1 VERSION
 
-Version 0.20    (March 21, 2015)
+Version 0.30    (March 31, 2015)
 
 =head1 BUGS
 
